package com.jz.common.aspect;

import java.lang.reflect.Method;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import com.alibaba.fastjson.JSONObject;
import com.jz.common.annotation.SysOperationLogAnnotation;
import com.jz.common.utils.HttpRequestUtil;
import com.jz.common.utils.web.SessionUtils;
import com.jz.dmp.modules.model.DmpOptLog;
import com.jz.dmp.modules.service.DmpOptLogService;

/**系统操作日志
 * @author ybz
 *
 */
@Aspect
@Component
public class SysOperationLogAspect {
	
	private static Logger logger = LoggerFactory.getLogger(SysOperationLogAspect.class);
	
	@Autowired
	private DmpOptLogService dmpOptLogService;

    @Pointcut("@annotation( com.jz.common.annotation.SysOperationLogAnnotation)")
    public void sysOperationLogPointCut(){

    }

    @Around("sysOperationLogPointCut()")
    public Object saveSysOperationLog(ProceedingJoinPoint pjp) throws Throwable{
        System.out.println("=============== 保存操作日志 ===============");
        
        //参数准备
        Date optTime = new Date();

        //保存日志
        DmpOptLog dmpOptLog = new DmpOptLog();
        
        //设置操作时间
        dmpOptLog.setOptTime(optTime);
        dmpOptLog.setCreateTime(optTime);

        //从切面织入点处通过反射机制获取织入点处的方法
        MethodSignature signature = (MethodSignature) pjp.getSignature();
        //获取切入点所在的方法
        Method method = signature.getMethod();
        //获取操作
        SysOperationLogAnnotation operationLogAnnotation = method.getAnnotation(SysOperationLogAnnotation.class);
        if (operationLogAnnotation != null) {
        	String optType = operationLogAnnotation.actionType();
            String optDesc = operationLogAnnotation.descrption();
            dmpOptLog.setOptType(optType);//保存获取的操作
            dmpOptLog.setOptDesc(optDesc);
        }
        //获取请求的类名
        String className = pjp.getTarget().getClass().getName();
        //获取请求的方法名
        String methodName = method.getName();
        dmpOptLog.setMethod(className + "." + methodName);

        //请求的参数
        String[] argNames = signature.getParameterNames(); // 参数名
        Object[] argObjs = pjp.getArgs() ;
        Map<String, Object> paramMap = new HashMap<String, Object>();
        for (int index=0; index<argNames.length; index++) {
        	String argName = argNames[index];
        	Object argObj = argObjs[index];
        	if (argObj instanceof HttpServletRequest) {
				continue;
			}
			paramMap.put(argName, argObj);
		}
        dmpOptLog.setRequestParam(JSONObject.toJSONString(paramMap));

		// 保存操作用户信息
		String userId = SessionUtils.getCurrentUserId();
		dmpOptLog.setUserId(Integer.parseInt(userId));
		dmpOptLog.setUserName(SessionUtils.getCurrentUserName());
		dmpOptLog.setCreateUserId(Integer.parseInt(userId));
		
        //设置ip
        String optIp = "";
        try {
        	// 获取request
            HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes()).getRequest();
        	optIp = HttpRequestUtil.getNginxRealIp(request);
		} catch (Exception e) {
			e.printStackTrace();
			logger.info("ip获取异常："+e.getMessage());
		}
        dmpOptLog.setOptIp(optIp);
        
        Object obj;
		try {
			obj = pjp.proceed();
	        
	        dmpOptLog.setOptResult(JSONObject.toJSONString(obj));
	        
	        //调用service保存SysLog实体类到数据库
	        try {
				dmpOptLogService.add(dmpOptLog, null);
			} catch (Exception e) {
				logger.info("插入操作日志异常。e:"+e.getMessage());
				e.printStackTrace();
			}
		} catch (Throwable e1) {
			e1.printStackTrace();
			
			dmpOptLog.setOptResult(e1.getMessage());
			dmpOptLog.setRemark("系统异常");
	        
	        //调用service保存SysLog实体类到数据库
	        try {
				dmpOptLogService.add(dmpOptLog, null);
			} catch (Exception e) {
				logger.info("插入操作日志异常。e:"+e.getMessage());
				e.printStackTrace();
			}
	        
			throw e1;
		}
        
        return obj;
    }
    
    
}
