package com.jz.dmp.modules.service.projconfig.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.CommConstant;
import com.jz.common.constant.StatuConstant;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.projconfig.bean.DmpComputEngineDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoBatch;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoDto;
import com.jz.dmp.modules.controller.projconfig.bean.DmpPublicConfigInfoRequest;
import com.jz.dmp.modules.controller.projconfig.bean.MyDmpComputEngineConverter;
import com.jz.dmp.modules.dao.projconfig.DmpComputEngineMapper;
import com.jz.dmp.modules.dao.projconfig.DmpComputEngineParamMapper;
import com.jz.dmp.modules.dao.projconfig.DmpPublicConfigInfoMapper;
import com.jz.dmp.modules.model.DmpComputEngine;
import com.jz.dmp.modules.model.DmpComputEngineParam;
import com.jz.dmp.modules.model.DmpPublicConfigInfo;
import com.jz.dmp.modules.service.projconfig.DmpComputEngineParamService;
import com.jz.dmp.modules.service.projconfig.DmpPublicConfigInfoService;

/**
 * 公共配置表服务的实现?
 * 
 * @author ybz
 *
 */
@Service("dmpPublicConfigInfoService")
public class DmpPublicConfigInfoServiceImpl extends BaseService implements DmpPublicConfigInfoService {

	private static Logger logger = LoggerFactory.getLogger(DmpPublicConfigInfoServiceImpl.class);

	@Autowired
	private DmpPublicConfigInfoMapper dmpPublicConfigInfoMapper;
	
	@Autowired
	private DmpComputEngineMapper dmpComputEngineMapper;
	
	@Autowired
	private DmpComputEngineParamMapper dmpComputEngineParamMapper;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#findList(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpPublicConfigInfoDto> findListWithPage(DmpPublicConfigInfoRequest dmpPublicConfigInfoRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpPublicConfigInfoDto> pageInfoResponse = new PageInfoResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpPublicConfigInfoRequest.getPublicConfigId() != null) {
			param.put("publicConfigId", dmpPublicConfigInfoRequest.getPublicConfigId());
		}
		//是否启动kerberos(单选按钮)(0：不启用，1，启用)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosIsenable())) {
			param.put("kerberosIsenable", dmpPublicConfigInfoRequest.getKerberosIsenable());
		}
		//jaas默认Client名称
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasClientName())) {
			param.put("kerberosJaasClientName", dmpPublicConfigInfoRequest.getKerberosJaasClientName());
		}
		//krb5地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKrb5Conf())) {
			param.put("kerberosKrb5Conf", dmpPublicConfigInfoRequest.getKerberosKrb5Conf());
		}
		//jaas地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasConf())) {
			param.put("kerberosJaasConf", dmpPublicConfigInfoRequest.getKerberosJaasConf());
		}
		//FQDN
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosFqdn())) {
			param.put("kerberosFqdn", dmpPublicConfigInfoRequest.getKerberosFqdn());
		}
		//keytab地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabConf())) {
			param.put("kerberosKeytabConf", dmpPublicConfigInfoRequest.getKerberosKeytabConf());
		}
		//keytab用户
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabUser())) {
			param.put("kerberosKeytabUser", dmpPublicConfigInfoRequest.getKerberosKeytabUser());
		}
		//spark专用jaas
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosSparkJaasConf())) {
			param.put("kerberosSparkJaasConf", dmpPublicConfigInfoRequest.getKerberosSparkJaasConf());
		}
		//提交 XML默认defaultFS
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsHttpPath())) {
			param.put("hdfsHttpPath", dmpPublicConfigInfoRequest.getHdfsHttpPath());
		}
		//提交XML到HDFS路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsSyncingPath())) {
			param.put("hdfsSyncingPath", dmpPublicConfigInfoRequest.getHdfsSyncingPath());
		}
		//Hadoop 用户名
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsUserName())) {
			param.put("hdfsUserName", dmpPublicConfigInfoRequest.getHdfsUserName());
		}
		//Kafka connector url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaConectorUrl())) {
			param.put("kafkaConectorUrl", dmpPublicConfigInfoRequest.getKafkaConectorUrl());
		}
		//schema register url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl())) {
			param.put("kafkaSchemaRegisterUrl", dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl());
		}
		//kafka bootstarp servers
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaBootstrapServers())) {
			param.put("kafkaBootstrapServers", dmpPublicConfigInfoRequest.getKafkaBootstrapServers());
		}
		//执行shell任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExec())) {
			param.put("azkabanExectorShellExec", dmpPublicConfigInfoRequest.getAzkabanExectorShellExec());
		}
		//执行impala sql任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec())) {
			param.put("azkabanExectorSqlExec", dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec());
		}
		//执行数据同步任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec())) {
			param.put("azkabanExectorXmlExec", dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec());
		}
		//调度执行sql路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath())) {
			param.put("azkabanExectorSqlPath", dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath());
		}
		//调度执行shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellPath())) {
			param.put("azkabanExectorShellPath", dmpPublicConfigInfoRequest.getAzkabanExectorShellPath());
		}
		//task配置文件路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath())) {
			param.put("azkabanLocalTaskFilePath", dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath());
		}
		//执行数据导出任务命令的shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData())) {
			param.put("azkabanExectorShellExportData", dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData());
		}
		//调度web服务地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanMonitorUrl())) {
			param.put("azkabanMonitorUrl", dmpPublicConfigInfoRequest.getAzkabanMonitorUrl());
		}
		//元数据服务web地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAtlasMonitorUrl())) {
			param.put("atlasMonitorUrl", dmpPublicConfigInfoRequest.getAtlasMonitorUrl());
		}
		//备注
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getRemark())) {
			param.put("remark", dmpPublicConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpPublicConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpPublicConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpPublicConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpPublicConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpPublicConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpPublicConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpPublicConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpPublicConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpPublicConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpPublicConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpPublicConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpPublicConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpPublicConfigInfoRequest.getUpdateTimeEnd());
		}

		PageHelper.startPage(dmpPublicConfigInfoRequest.getPageNum(), dmpPublicConfigInfoRequest.getPageSize());
		List<DmpPublicConfigInfoDto> list = dmpPublicConfigInfoMapper.findList(param);
		PageInfo<DmpPublicConfigInfoDto> pageInfo = new PageInfo<>(list);

		pageInfoResponse.setCode(StatuConstant.SUCCESS_CODE);
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#findList(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpPublicConfigInfoDto> findList(DmpPublicConfigInfoRequest dmpPublicConfigInfoRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpPublicConfigInfoDto> baseBeanResponse = new BaseBeanResponse<>();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpPublicConfigInfoRequest.getPublicConfigId() != null) {
			param.put("publicConfigId", dmpPublicConfigInfoRequest.getPublicConfigId());
		}
		//是否启动kerberos(单选按钮)(0：不启用，1，启用)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosIsenable())) {
			param.put("kerberosIsenable", dmpPublicConfigInfoRequest.getKerberosIsenable());
		}
		//jaas默认Client名称
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasClientName())) {
			param.put("kerberosJaasClientName", dmpPublicConfigInfoRequest.getKerberosJaasClientName());
		}
		//krb5地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKrb5Conf())) {
			param.put("kerberosKrb5Conf", dmpPublicConfigInfoRequest.getKerberosKrb5Conf());
		}
		//jaas地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasConf())) {
			param.put("kerberosJaasConf", dmpPublicConfigInfoRequest.getKerberosJaasConf());
		}
		//FQDN
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosFqdn())) {
			param.put("kerberosFqdn", dmpPublicConfigInfoRequest.getKerberosFqdn());
		}
		//keytab地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabConf())) {
			param.put("kerberosKeytabConf", dmpPublicConfigInfoRequest.getKerberosKeytabConf());
		}
		//keytab用户
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabUser())) {
			param.put("kerberosKeytabUser", dmpPublicConfigInfoRequest.getKerberosKeytabUser());
		}
		//spark专用jaas
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosSparkJaasConf())) {
			param.put("kerberosSparkJaasConf", dmpPublicConfigInfoRequest.getKerberosSparkJaasConf());
		}
		//提交 XML默认defaultFS
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsHttpPath())) {
			param.put("hdfsHttpPath", dmpPublicConfigInfoRequest.getHdfsHttpPath());
		}
		//提交XML到HDFS路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsSyncingPath())) {
			param.put("hdfsSyncingPath", dmpPublicConfigInfoRequest.getHdfsSyncingPath());
		}
		//Hadoop 用户名
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsUserName())) {
			param.put("hdfsUserName", dmpPublicConfigInfoRequest.getHdfsUserName());
		}
		//Kafka connector url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaConectorUrl())) {
			param.put("kafkaConectorUrl", dmpPublicConfigInfoRequest.getKafkaConectorUrl());
		}
		//schema register url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl())) {
			param.put("kafkaSchemaRegisterUrl", dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl());
		}
		//kafka bootstarp servers
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaBootstrapServers())) {
			param.put("kafkaBootstrapServers", dmpPublicConfigInfoRequest.getKafkaBootstrapServers());
		}
		//执行shell任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExec())) {
			param.put("azkabanExectorShellExec", dmpPublicConfigInfoRequest.getAzkabanExectorShellExec());
		}
		//执行impala sql任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec())) {
			param.put("azkabanExectorSqlExec", dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec());
		}
		//执行数据同步任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec())) {
			param.put("azkabanExectorXmlExec", dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec());
		}
		//调度执行sql路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath())) {
			param.put("azkabanExectorSqlPath", dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath());
		}
		//调度执行shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellPath())) {
			param.put("azkabanExectorShellPath", dmpPublicConfigInfoRequest.getAzkabanExectorShellPath());
		}
		//task配置文件路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath())) {
			param.put("azkabanLocalTaskFilePath", dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath());
		}
		//执行数据导出任务命令的shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData())) {
			param.put("azkabanExectorShellExportData", dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData());
		}
		//调度web服务地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanMonitorUrl())) {
			param.put("azkabanMonitorUrl", dmpPublicConfigInfoRequest.getAzkabanMonitorUrl());
		}
		//元数据服务web地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAtlasMonitorUrl())) {
			param.put("atlasMonitorUrl", dmpPublicConfigInfoRequest.getAtlasMonitorUrl());
		}
		//备注
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getRemark())) {
			param.put("remark", dmpPublicConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpPublicConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpPublicConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpPublicConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpPublicConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpPublicConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpPublicConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpPublicConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpPublicConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpPublicConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpPublicConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpPublicConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpPublicConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpPublicConfigInfoRequest.getUpdateTimeEnd());
		}

		List<DmpPublicConfigInfoDto> list = dmpPublicConfigInfoMapper.findList(param);
		if (!CollectionUtils.isEmpty(list)) {
			Map<String, Object> param2 = new HashMap<String, Object>();
			List<DmpComputEngineDto> dmpComputEngineDtos = dmpComputEngineMapper.findList(param2);
			
			for (DmpPublicConfigInfoDto dmpPublicConfigInfoDto : list) {
				dmpPublicConfigInfoDto.setDmpComputEngineDtos(dmpComputEngineDtos);
			}
		}

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setDatas(list);
		return baseBeanResponse;
	}


	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#add(com.ycxc.vmts.entity.DmpPublicConfigInfo,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpPublicConfigInfo> add(DmpPublicConfigInfo dmpPublicConfigInfo, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpPublicConfigInfo> baseBeanResponse = new BaseBeanResponse<>();

		/*$*setPublicConfigIdCodeReplace*$*/
		// 创建人
		dmpPublicConfigInfo.setCreateUserId(getHttpRequestUserId(httpRequest));
		// 创建时间
		dmpPublicConfigInfo.setCreateTime(new Date());

		dmpPublicConfigInfoMapper.insertSelective(dmpPublicConfigInfo);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpPublicConfigInfo);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#edit(com.ycxc.vmts.entity.DmpPublicConfigInfo,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpPublicConfigInfo> edit(DmpPublicConfigInfo dmpPublicConfigInfo, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpPublicConfigInfo> baseBeanResponse = new BaseBeanResponse<>();

		// 修改人
		dmpPublicConfigInfo.setUpdateUserId(getHttpRequestUserId(httpRequest));
		// 修改时间
		dmpPublicConfigInfo.setUpdateTime(new Date());

		dmpPublicConfigInfoMapper.updateByPrimaryKeySelective(dmpPublicConfigInfo);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpPublicConfigInfo);

		return baseBeanResponse;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#addOrEdit(com.ycxc.vmts.entity.DmpPublicConfigInfo,
	 * javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpPublicConfigInfo> addOrEdit(DmpPublicConfigInfo dmpPublicConfigInfo, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpPublicConfigInfo> baseBeanResponse = new BaseBeanResponse<>();
		
		Integer publicConfigId = dmpPublicConfigInfo.getPublicConfigId();
		
		//计算引擎公共参数配置
		List<DmpComputEngineParam> params = new ArrayList<DmpComputEngineParam>();
		if (!CollectionUtils.isEmpty(dmpPublicConfigInfo.getComputEngines())) {
			params = dmpPublicConfigInfo.getComputEngines()
					.stream().flatMap(x->{
						return x.getParams().stream();
					}).collect(Collectors.toList());
		}
		
		if (null==publicConfigId) {//新增
			
			// 创建人
			dmpPublicConfigInfo.setCreateUserId(getHttpRequestUserId(httpRequest));
			// 创建时间
			dmpPublicConfigInfo.setCreateTime(new Date());

			dmpPublicConfigInfoMapper.insertSelective(dmpPublicConfigInfo);
			
			//保存计算引擎公共参数配置
			for (DmpComputEngineParam dmpComputEngineParam : params) {
				dmpComputEngineParam.setUpdateUserId(getHttpRequestUserId(httpRequest));
				dmpComputEngineParam.setUpdateTime(new Date());
				dmpComputEngineParamMapper.updateByPrimaryKeySelective(dmpComputEngineParam);
			}
			
			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("新增成功");
			baseBeanResponse.setData(dmpPublicConfigInfo);
		} else {//修改
			// 修改人
			dmpPublicConfigInfo.setUpdateUserId(getHttpRequestUserId(httpRequest));
			// 修改时间
			dmpPublicConfigInfo.setUpdateTime(new Date());

			dmpPublicConfigInfoMapper.updateByPrimaryKeySelective(dmpPublicConfigInfo);
			
			//保存计算引擎公共参数配置
			for (DmpComputEngineParam dmpComputEngineParam : params) {
				dmpComputEngineParam.setUpdateUserId(getHttpRequestUserId(httpRequest));
				dmpComputEngineParam.setUpdateTime(new Date());
				dmpComputEngineParamMapper.updateByPrimaryKeySelective(dmpComputEngineParam);
			}

			baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
			baseBeanResponse.setMessage("修改成功");
			baseBeanResponse.setData(dmpPublicConfigInfo);
		}
		
		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#findById(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpPublicConfigInfoDto> findById(Integer publicConfigId, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpPublicConfigInfoDto> baseBeanResponse = new BaseBeanResponse<>();

		DmpPublicConfigInfoDto dmpPublicConfigInfoDto = dmpPublicConfigInfoMapper.findById(publicConfigId);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpPublicConfigInfoDto);

		return baseBeanResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse deleteById(Integer publicConfigId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpPublicConfigInfoMapper.deleteByPrimaryKey(publicConfigId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDeleteById(Integer publicConfigId, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpPublicConfigInfoMapper.softDeleteByPrimaryKey(publicConfigId);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse delete(DmpPublicConfigInfoRequest dmpPublicConfigInfoRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpPublicConfigInfoRequest.getPublicConfigId() != null) {
			param.put("publicConfigId", dmpPublicConfigInfoRequest.getPublicConfigId());
		}
		//是否启动kerberos(单选按钮)(0：不启用，1，启用)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosIsenable())) {
			param.put("kerberosIsenable", dmpPublicConfigInfoRequest.getKerberosIsenable());
		}
		//jaas默认Client名称
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasClientName())) {
			param.put("kerberosJaasClientName", dmpPublicConfigInfoRequest.getKerberosJaasClientName());
		}
		//krb5地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKrb5Conf())) {
			param.put("kerberosKrb5Conf", dmpPublicConfigInfoRequest.getKerberosKrb5Conf());
		}
		//jaas地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasConf())) {
			param.put("kerberosJaasConf", dmpPublicConfigInfoRequest.getKerberosJaasConf());
		}
		//FQDN
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosFqdn())) {
			param.put("kerberosFqdn", dmpPublicConfigInfoRequest.getKerberosFqdn());
		}
		//keytab地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabConf())) {
			param.put("kerberosKeytabConf", dmpPublicConfigInfoRequest.getKerberosKeytabConf());
		}
		//keytab用户
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabUser())) {
			param.put("kerberosKeytabUser", dmpPublicConfigInfoRequest.getKerberosKeytabUser());
		}
		//spark专用jaas
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosSparkJaasConf())) {
			param.put("kerberosSparkJaasConf", dmpPublicConfigInfoRequest.getKerberosSparkJaasConf());
		}
		//提交 XML默认defaultFS
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsHttpPath())) {
			param.put("hdfsHttpPath", dmpPublicConfigInfoRequest.getHdfsHttpPath());
		}
		//提交XML到HDFS路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsSyncingPath())) {
			param.put("hdfsSyncingPath", dmpPublicConfigInfoRequest.getHdfsSyncingPath());
		}
		//Hadoop 用户名
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsUserName())) {
			param.put("hdfsUserName", dmpPublicConfigInfoRequest.getHdfsUserName());
		}
		//Kafka connector url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaConectorUrl())) {
			param.put("kafkaConectorUrl", dmpPublicConfigInfoRequest.getKafkaConectorUrl());
		}
		//schema register url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl())) {
			param.put("kafkaSchemaRegisterUrl", dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl());
		}
		//kafka bootstarp servers
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaBootstrapServers())) {
			param.put("kafkaBootstrapServers", dmpPublicConfigInfoRequest.getKafkaBootstrapServers());
		}
		//执行shell任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExec())) {
			param.put("azkabanExectorShellExec", dmpPublicConfigInfoRequest.getAzkabanExectorShellExec());
		}
		//执行impala sql任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec())) {
			param.put("azkabanExectorSqlExec", dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec());
		}
		//执行数据同步任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec())) {
			param.put("azkabanExectorXmlExec", dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec());
		}
		//调度执行sql路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath())) {
			param.put("azkabanExectorSqlPath", dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath());
		}
		//调度执行shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellPath())) {
			param.put("azkabanExectorShellPath", dmpPublicConfigInfoRequest.getAzkabanExectorShellPath());
		}
		//task配置文件路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath())) {
			param.put("azkabanLocalTaskFilePath", dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath());
		}
		//执行数据导出任务命令的shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData())) {
			param.put("azkabanExectorShellExportData", dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData());
		}
		//调度web服务地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanMonitorUrl())) {
			param.put("azkabanMonitorUrl", dmpPublicConfigInfoRequest.getAzkabanMonitorUrl());
		}
		//元数据服务web地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAtlasMonitorUrl())) {
			param.put("atlasMonitorUrl", dmpPublicConfigInfoRequest.getAtlasMonitorUrl());
		}
		//备注
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getRemark())) {
			param.put("remark", dmpPublicConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpPublicConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpPublicConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpPublicConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpPublicConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpPublicConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpPublicConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpPublicConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpPublicConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpPublicConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpPublicConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpPublicConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpPublicConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpPublicConfigInfoRequest.getUpdateTimeEnd());
		}

		dmpPublicConfigInfoMapper.delete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#deleteById(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseResponse softDelete(DmpPublicConfigInfoRequest dmpPublicConfigInfoRequest, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpPublicConfigInfoRequest.getPublicConfigId() != null) {
			param.put("publicConfigId", dmpPublicConfigInfoRequest.getPublicConfigId());
		}
		//是否启动kerberos(单选按钮)(0：不启用，1，启用)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosIsenable())) {
			param.put("kerberosIsenable", dmpPublicConfigInfoRequest.getKerberosIsenable());
		}
		//jaas默认Client名称
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasClientName())) {
			param.put("kerberosJaasClientName", dmpPublicConfigInfoRequest.getKerberosJaasClientName());
		}
		//krb5地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKrb5Conf())) {
			param.put("kerberosKrb5Conf", dmpPublicConfigInfoRequest.getKerberosKrb5Conf());
		}
		//jaas地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosJaasConf())) {
			param.put("kerberosJaasConf", dmpPublicConfigInfoRequest.getKerberosJaasConf());
		}
		//FQDN
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosFqdn())) {
			param.put("kerberosFqdn", dmpPublicConfigInfoRequest.getKerberosFqdn());
		}
		//keytab地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabConf())) {
			param.put("kerberosKeytabConf", dmpPublicConfigInfoRequest.getKerberosKeytabConf());
		}
		//keytab用户
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosKeytabUser())) {
			param.put("kerberosKeytabUser", dmpPublicConfigInfoRequest.getKerberosKeytabUser());
		}
		//spark专用jaas
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKerberosSparkJaasConf())) {
			param.put("kerberosSparkJaasConf", dmpPublicConfigInfoRequest.getKerberosSparkJaasConf());
		}
		//提交 XML默认defaultFS
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsHttpPath())) {
			param.put("hdfsHttpPath", dmpPublicConfigInfoRequest.getHdfsHttpPath());
		}
		//提交XML到HDFS路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsSyncingPath())) {
			param.put("hdfsSyncingPath", dmpPublicConfigInfoRequest.getHdfsSyncingPath());
		}
		//Hadoop 用户名
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getHdfsUserName())) {
			param.put("hdfsUserName", dmpPublicConfigInfoRequest.getHdfsUserName());
		}
		//Kafka connector url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaConectorUrl())) {
			param.put("kafkaConectorUrl", dmpPublicConfigInfoRequest.getKafkaConectorUrl());
		}
		//schema register url
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl())) {
			param.put("kafkaSchemaRegisterUrl", dmpPublicConfigInfoRequest.getKafkaSchemaRegisterUrl());
		}
		//kafka bootstarp servers
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getKafkaBootstrapServers())) {
			param.put("kafkaBootstrapServers", dmpPublicConfigInfoRequest.getKafkaBootstrapServers());
		}
		//执行shell任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExec())) {
			param.put("azkabanExectorShellExec", dmpPublicConfigInfoRequest.getAzkabanExectorShellExec());
		}
		//执行impala sql任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec())) {
			param.put("azkabanExectorSqlExec", dmpPublicConfigInfoRequest.getAzkabanExectorSqlExec());
		}
		//执行数据同步任务命令
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec())) {
			param.put("azkabanExectorXmlExec", dmpPublicConfigInfoRequest.getAzkabanExectorXmlExec());
		}
		//调度执行sql路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath())) {
			param.put("azkabanExectorSqlPath", dmpPublicConfigInfoRequest.getAzkabanExectorSqlPath());
		}
		//调度执行shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellPath())) {
			param.put("azkabanExectorShellPath", dmpPublicConfigInfoRequest.getAzkabanExectorShellPath());
		}
		//task配置文件路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath())) {
			param.put("azkabanLocalTaskFilePath", dmpPublicConfigInfoRequest.getAzkabanLocalTaskFilePath());
		}
		//执行数据导出任务命令的shell路径
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData())) {
			param.put("azkabanExectorShellExportData", dmpPublicConfigInfoRequest.getAzkabanExectorShellExportData());
		}
		//调度web服务地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAzkabanMonitorUrl())) {
			param.put("azkabanMonitorUrl", dmpPublicConfigInfoRequest.getAzkabanMonitorUrl());
		}
		//元数据服务web地址
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getAtlasMonitorUrl())) {
			param.put("atlasMonitorUrl", dmpPublicConfigInfoRequest.getAtlasMonitorUrl());
		}
		//备注
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getRemark())) {
			param.put("remark", dmpPublicConfigInfoRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpPublicConfigInfoRequest.getDataStatus())) {
			param.put("dataStatus", dmpPublicConfigInfoRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpPublicConfigInfoRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpPublicConfigInfoRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpPublicConfigInfoRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpPublicConfigInfoRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpPublicConfigInfoRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpPublicConfigInfoRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpPublicConfigInfoRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpPublicConfigInfoRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpPublicConfigInfoRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpPublicConfigInfoRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpPublicConfigInfoRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpPublicConfigInfoRequest.getUpdateTimeEnd());
		}

		dmpPublicConfigInfoMapper.softDelete(param);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ycxc.vmts.service.DmpPublicConfigInfoService#addBatch(com.ycxc.vmts.controller.bas.
	 * bean.DmpPublicConfigInfoVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public BaseBeanResponse<DmpPublicConfigInfoBatch> addBatch(DmpPublicConfigInfoBatch dmpPublicConfigInfoBatch, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpPublicConfigInfoBatch> baseBeanResponse = new BaseBeanResponse<>();

		List<DmpPublicConfigInfo> dmpPublicConfigInfos = dmpPublicConfigInfoBatch.getDmpPublicConfigInfos();

		if (CollectionUtils.isEmpty(dmpPublicConfigInfos)) {
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}

		dmpPublicConfigInfos = dmpPublicConfigInfos.stream().map(dmpPublicConfigInfo -> {
			/*$*setPublicConfigIdCodeReplace*$*/
			// 创建人
			try {
				dmpPublicConfigInfo.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			// 创建时间
			dmpPublicConfigInfo.setCreateTime(new Date());

			return dmpPublicConfigInfo;
		}).collect(Collectors.toList());

		dmpPublicConfigInfoMapper.insertBatch(dmpPublicConfigInfos);

		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpPublicConfigInfoBatch);

		return baseBeanResponse;
	}

	/**
	 *批量删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpPublicConfigInfoMapper.deleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("删除成功");

		return baseResponse;
	}

	/**
	 *批量软删除
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse softDeleteByIds(List<Integer> idList, HttpServletRequest httpRequest) throws Exception {
		BaseResponse baseResponse = new BaseResponse();

		dmpPublicConfigInfoMapper.softDeleteByIds(idList);

		baseResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseResponse.setMessage("软删除成功");

		return baseResponse;
	}

	/**
	 *获取公共配置
	 */
	@Override
	public BaseBeanResponse<DmpPublicConfigInfoDto> findOne(HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpPublicConfigInfoDto> baseBeanResponse = new BaseBeanResponse<DmpPublicConfigInfoDto>();
		
		DmpPublicConfigInfoDto dmpPublicConfigInfoDto = new DmpPublicConfigInfoDto();
		
		Map<String, Object> param = new HashMap<String, Object>();
		List<DmpPublicConfigInfoDto> list = dmpPublicConfigInfoMapper.findList(param);
		if (!CollectionUtils.isEmpty(list)) {
			dmpPublicConfigInfoDto = list.get(0);
			Map<String, Object> param2 = new HashMap<String, Object>();
			List<DmpComputEngineDto> dmpComputEngineDtos = dmpComputEngineMapper.findList(param2);
			dmpPublicConfigInfoDto.setDmpComputEngineDtos(dmpComputEngineDtos);
		}
		
		baseBeanResponse.setCode(StatuConstant.SUCCESS_CODE);
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpPublicConfigInfoDto);
		
		return baseBeanResponse;
	}

}
